==> diffie_hellman-1.1.1.tar.gz: test/src/keys/codec/dh_private_key_codec_test.dart <==
import 'package:diffie_hellman/diffie_hellman.dart';
import 'package:diffie_hellman/src/keys/codec/dh_key_codec.dart';
import 'package:diffie_hellman/src/keys/codec/dh_private_key_codec.dart';
import 'package:test/test.dart';

void main() {
  DhPrivateKeyCodec codec = DhPrivateKeyCodec();
  test('Test getters', () {
    expect(DhKeyCodec.oId, [1, 2, 840, 113549, 1, 3, 1]);
    expect(codec.beginDelimiter, '-----BEGIN PRIVATE KEY-----');
    expect(codec.endDelimiter, '-----END PRIVATE KEY-----');
  });
  group('Test decode', () {
    test('success', () {
      String pem = '-----BEGIN PRIVATE KEY-----'
          'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ'
          '58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I'
          '80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVd'
          'WSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCY'
          'hHLBaHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7l'
          'mPi/n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/Cfbj'
          'eH3DcsQFyPbCj3O1ZjErOPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5Os'
          'ohJWkomtg1Lf44r+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U'
          '4PytlhOzbni3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlIdKpT0HWmqOeELT3Ud/kR'
          'FaNOvulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
          'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
          '-----END PRIVATE KEY-----';

      DhPrivateKey key = codec.decode(pem);

      expect(key, isA<DhPrivateKey>());
      expect(
        key.value,
        BigInt.parse(
          '13597176153093116618070232578081602614364742364104437899699993267303'
          '6905780735235406980777367427004676545694507106927221225778421182'
          '5190132346824691772564178125040962309153669511289086635688568832'
          '5218566218861674035292708914228206720627587485922453112227484026'
          '8180466781446591404081455756493500146644285054188081111551074635'
          '1572065836786554985090432297171976054359881431929702174773875000'
          '4158668184115715230324040615323027257454379086758569201508878917'
          '6724944919175113880412540462035212263914099279754179894968277145'
          '6569105479021840634419510253664189153229791701202943881710038146'
          '045862791511979233341105251679559183381811752',
        ),
      );
      expect(key.parameter.g, 2);
      expect(
        key.parameter.length,
        isNull,
      );
      expect(
        key.parameter.p,
        BigInt.parse(
          '1705981236470358725694168947912340905184016456649447827905035366'
          '423517535309908785587707055879384617579501090023314190176825'
          '906194053926198680818787330824514093789425038991297310899347'
          '879603007390591295367927989200428479181392167186038274353771'
          '051467944239198579360702639880632257276543722599876705523832'
          '383110847754263857714814930133028553636527166334698763092635'
          '309746869886837672874917937355659269162487244401397961380983'
          '492065819046040513532179748873242190063094003226840334898050'
          '065909470313763757295606726586211667148768695097521928028357'
          '150201410623989347868579314525119658923402674799093063288032'
          '9238408161847',
        ),
      );
      expect(key.parameter.p.bitLength, 2048);
    });
    test('error', () {
      String pem = '-----BEGIN PRIVATE KEY-----'
          'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ'
          '58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I'
          '80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVd'
          'WSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCY'
          'hHLBaHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7l'
          'mPi/n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/Cfbj'
          'eH3DcsQFyPbCj3O1ZjErOPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5Os'
          'ohJWkomtg1Lf44r+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U'
          '4PytlhOzbni3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlsdfdsfdsfIdKpT0HWmqOeELT3Ud/kR'
          'FaNOvulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
          'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
          '-----END PRIVATE KEY-----';

      expect(
        () => codec.decode(pem),
        throwsA(isA<FormatException>()),
      );
    });
  });

  group('Test encode', () {
    test('success', () {
      DhPrivateKey privateKey = DhPrivateKey(
        BigInt.parse(
          '13597176153093116618070232578081602614364742364104437899699993267303'
          '6905780735235406980777367427004676545694507106927221225778421182'
          '5190132346824691772564178125040962309153669511289086635688568832'
          '5218566218861674035292708914228206720627587485922453112227484026'
          '8180466781446591404081455756493500146644285054188081111551074635'
          '1572065836786554985090432297171976054359881431929702174773875000'
          '4158668184115715230324040615323027257454379086758569201508878917'
          '6724944919175113880412540462035212263914099279754179894968277145'
          '6569105479021840634419510253664189153229791701202943881710038146'
          '045862791511979233341105251679559183381811752',
        ),
        parameter: DhParameter(
          g: 2,
          p: BigInt.parse(
            '1705981236470358725694168947912340905184016456649447827905035366'
            '423517535309908785587707055879384617579501090023314190176825'
            '906194053926198680818787330824514093789425038991297310899347'
            '879603007390591295367927989200428479181392167186038274353771'
            '051467944239198579360702639880632257276543722599876705523832'
            '383110847754263857714814930133028553636527166334698763092635'
            '309746869886837672874917937355659269162487244401397961380983'
            '492065819046040513532179748873242190063094003226840334898050'
            '065909470313763757295606726586211667148768695097521928028357'
            '150201410623989347868579314525119658923402674799093063288032'
            '9238408161847',
          ),
        ),
      );

      String pem = codec.encode(privateKey);

      expect(
        pem,
        '-----BEGIN PRIVATE KEY-----'
        'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIc'
        'jxlcFdybmHMukoDlQbpv7gnXQ58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlC'
        'jHpmdcV6NUEiD2T39xVFxX8p8+I80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3'
        'oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6Ag'
        'zL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLBaHDLO3xptDI3g/rD4dFmAve60h'
        'w6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/n8StPoThQwo+l5wL4OuJo'
        'j+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/CfbjeH3DcsQFyPbCj3O1ZjEr'
        'OPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5OsohJWkomtg1Lf44r'
        '+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U4PytlhOzbn'
        'i3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlIdKpT0HWmqOeELT3Ud/kRFaNOv'
        'ulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
        'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
        '-----END PRIVATE KEY-----',
      );
    });
  });
}

==> diffie_hellman-1.1.4.tar.gz: test/src/keys/codec/dh_private_key_codec_test.dart <==
import 'package:diffie_hellman/diffie_hellman.dart';
import 'package:diffie_hellman/src/keys/codec/dh_key_codec.dart';
import 'package:diffie_hellman/src/keys/codec/dh_private_key_codec.dart';
import 'package:test/test.dart';

void main() {
  DhPrivateKeyCodec codec = DhPrivateKeyCodec();
  test('Test getters', () {
    expect(DhKeyCodec.oId, [1, 2, 840, 113549, 1, 3, 1]);
    expect(codec.beginDelimiter, '-----BEGIN PRIVATE KEY-----');
    expect(codec.endDelimiter, '-----END PRIVATE KEY-----');
  });
  group('Test decode', () {
    test('success', () {
      String pem = '-----BEGIN PRIVATE KEY-----'
          'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ'
          '58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I'
          '80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVd'
          'WSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCY'
          'hHLBaHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7l'
          'mPi/n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/Cfbj'
          'eH3DcsQFyPbCj3O1ZjErOPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5Os'
          'ohJWkomtg1Lf44r+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U'
          '4PytlhOzbni3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlIdKpT0HWmqOeELT3Ud/kR'
          'FaNOvulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
          'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
          '-----END PRIVATE KEY-----';

      DhPrivateKey key = codec.decode(pem);

      expect(key, isA<DhPrivateKey>());
      expect(
        key.value,
        BigInt.parse(
          '13597176153093116618070232578081602614364742364104437899699993267303'
          '6905780735235406980777367427004676545694507106927221225778421182'
          '5190132346824691772564178125040962309153669511289086635688568832'
          '5218566218861674035292708914228206720627587485922453112227484026'
          '8180466781446591404081455756493500146644285054188081111551074635'
          '1572065836786554985090432297171976054359881431929702174773875000'
          '4158668184115715230324040615323027257454379086758569201508878917'
          '6724944919175113880412540462035212263914099279754179894968277145'
          '6569105479021840634419510253664189153229791701202943881710038146'
          '045862791511979233341105251679559183381811752',
        ),
      );
      expect(key.parameter.g, BigInt.two);
      expect(
        key.parameter.l,
        isNull,
      );
      expect(
        key.parameter.p,
        BigInt.parse(
          '1705981236470358725694168947912340905184016456649447827905035366'
          '423517535309908785587707055879384617579501090023314190176825'
          '906194053926198680818787330824514093789425038991297310899347'
          '879603007390591295367927989200428479181392167186038274353771'
          '051467944239198579360702639880632257276543722599876705523832'
          '383110847754263857714814930133028553636527166334698763092635'
          '309746869886837672874917937355659269162487244401397961380983'
          '492065819046040513532179748873242190063094003226840334898050'
          '065909470313763757295606726586211667148768695097521928028357'
          '150201410623989347868579314525119658923402674799093063288032'
          '9238408161847',
        ),
      );
      expect(key.parameter.p.bitLength, 2048);
    });
    test('error', () {
      String pem = '-----BEGIN PRIVATE KEY-----'
          'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIcjxlcFdybmHMukoDlQbpv7gnXQ'
          '58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlCjHpmdcV6NUEiD2T39xVFxX8p8+I'
          '80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3oVLEhJdRRjRvX88gT77kiYOWnjVd'
          'WSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6AgzL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCY'
          'hHLBaHDLO3xptDI3g/rD4dFmAve60hw6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7l'
          'mPi/n8StPoThQwo+l5wL4OuJoj+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/Cfbj'
          'eH3DcsQFyPbCj3O1ZjErOPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5Os'
          'ohJWkomtg1Lf44r+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U'
          '4PytlhOzbni3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlsdfdsfdsfIdKpT0HWmqOeELT3Ud/kR'
          'FaNOvulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
          'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
          '-----END PRIVATE KEY-----';

      expect(
        () => codec.decode(pem),
        throwsA(isA<FormatException>()),
      );
    });
  });

  group('Test encode', () {
    test('success', () {
      DhPrivateKey privateKey = DhPrivateKey(
        BigInt.parse(
          '13597176153093116618070232578081602614364742364104437899699993267303'
          '6905780735235406980777367427004676545694507106927221225778421182'
          '5190132346824691772564178125040962309153669511289086635688568832'
          '5218566218861674035292708914228206720627587485922453112227484026'
          '8180466781446591404081455756493500146644285054188081111551074635'
          '1572065836786554985090432297171976054359881431929702174773875000'
          '4158668184115715230324040615323027257454379086758569201508878917'
          '6724944919175113880412540462035212263914099279754179894968277145'
          '6569105479021840634419510253664189153229791701202943881710038146'
          '045862791511979233341105251679559183381811752',
        ),
        parameter: DhParameter(
          g: BigInt.two,
          p: BigInt.parse(
            '1705981236470358725694168947912340905184016456649447827905035366'
            '423517535309908785587707055879384617579501090023314190176825'
            '906194053926198680818787330824514093789425038991297310899347'
            '879603007390591295367927989200428479181392167186038274353771'
            '051467944239198579360702639880632257276543722599876705523832'
            '383110847754263857714814930133028553636527166334698763092635'
            '309746869886837672874917937355659269162487244401397961380983'
            '492065819046040513532179748873242190063094003226840334898050'
            '065909470313763757295606726586211667148768695097521928028357'
            '150201410623989347868579314525119658923402674799093063288032'
            '9238408161847',
          ),
        ),
      );

      String pem = codec.encode(privateKey);

      expect(
        pem,
        '-----BEGIN PRIVATE KEY-----'
        'MIICJgIBADCCARcGCSqGSIb3DQEDATCCAQgCggEBAIc'
        'jxlcFdybmHMukoDlQbpv7gnXQ58LfKITR+nZQbuRXeJCXHDm1sB40IrvRNzU1fGwlC'
        'jHpmdcV6NUEiD2T39xVFxX8p8+I80EKxopImraK2+Q9AKJKFOwyF7akwhggdRLg9lQ3'
        'oVLEhJdRRjRvX88gT77kiYOWnjVdWSs7/94dJrWDLxRKSbdt3C2T7eaoaFjb6Ag'
        'zL/LPLtl1Z4u9zprCgVBLDXaLl8P+4PCYhHLBaHDLO3xptDI3g/rD4dFmAve60h'
        'w6lcQe8DwUrepJATa3WGreRM3GmlzaHjia8y7lmPi/n8StPoThQwo+l5wL4OuJo'
        'j+AKSKuFNdSi0rVajcCAQIEggEEAoIBAEjucSf/CfbjeH3DcsQFyPbCj3O1ZjEr'
        'OPVfafN2sABD6S9/vvM3PDD5C+W+V5/hDPhSom7SoVWxa5OsohJWkomtg1Lf44r'
        '+SYq1rSYflUXBtzovuP6+8po1BJuwQ2Xlgu73pzVUpbs7eadMSG/U4PytlhOzbn'
        'i3Hs9jNFMQKYEk6oTx9MgAwuxRjAY1vJ+xFAlIdKpT0HWmqOeELT3Ud/kRFaNOv'
        'ulYLzMBuc3yeAlX5rAgfKRm43kILvgiZrNwh31QEPfwyRH0KsiwNU1lA404BsZY'
        'j3BrXtiwEO9dgxMuhMKz4xzpjL6rJxTAukJ0G2CzLCT9t47H9RgA9tz/0ig='
        '-----END PRIVATE KEY-----',
      );
    });
  });
}
